#this is INLD(indian natural language detection) package

you can use this package to detect language of following Indian Languages:
1. Hindi	-hn
2. English  -en
3. Bengali  -bg
4. Telugu   -tg
5. Malayalam -ml
6. Odia		 -od
7. Punjabi	 -pb
8. Punglish	 -png
9. Hinglish	 -hng
10. Marathi  -mr
11. Gujarati -gj
12. Kannada  -kd
13. Assamese -am

Before using this library please also install latest version of pickle.

more languages are being continuosly added


